# Pyskema

## About

Pyskema is a small module used to define schema for structured data.

The schema can be used to validate, document and generate data.

## Installation

Use `pip install pyskema`.
Pyskema does not have dependencies and is only standard Python 3.7+.

## Usage

Please refer to the [documentation](https://pyskema.readthedocs.io).
